#!/bin/sh

# This file is part of Libre Media Collection.

# Libre Media Collection: Project to provide free/libre software to be distributed in removable media.
# Copyright (C) 2016  Adonay "adfeno" Felipe Nogueira <adfeno@openmailbox.org> <https://libreplanet.org/wiki/User:Adfeno>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Variables are in Esperanto.

faraj_dosierujoj() {
	mkdir -p "./kopioj/$1" || exit 1
	cd "./kopioj/$1"
	mkdir "./Fontodosieroj"
	while read -r ciu_dosierujo; do
		ln -s "./Fontodosieroj" "./${ciu_dosierujo}"
	done <<-CIU_DOSIERUJO
		Archivos fuente
		Arquivos fonte
		Ficheiros fonte
		Source files
	CIU_DOSIERUJO
}

akiri_gnu_linux_pakajo() {
	. "/etc/os-release" || exit 2
	mkdir "./GNU+Linux" || exit 3
	cd "./GNU+Linux"
	if [ "$ID" = "debian" ] || echo "$ID_LIKE" | grep -iq '\(^\)\|\( \)debian\(\ )\|\($\)'; then
		apt-get download "$@"
	fi
	cd ".."
}

akiri_gnu_linux_fontodosieroj() {
	. "/etc/os-release" || exit 2
	mkdir "./Fontodosieroj/GNU+Linux" || exit 3
	cd "./Fontodosieroj/GNU+Linux"
	if [ "$ID" = "debian" ] || echo "$ID_LIKE" | grep -iq '\(^\)\|\( \)debian\(\ )\|\($\)'; then
		apt-get source "$@"
	fi
	cd "../.."
}

akiri_pakajo() {
	malnova_pwd="$PWD"
	if [ "$1" = "all" ] || [ "$1" = "ciuj" ] || [ "$1" = "icecat" ]; then
		faraj_dosierujoj "GNU IceCat"
		
		wget -P "./Fontodosieroj" "http://ftpmirror.gnu.org/gnuzilla/38.8.0-gnu2/icecat-38.8.0-gnu2.tar.bz2"
		
		ripeto=$((ripeto+1))
		while read -r ciu_celo; do
			case $ripeto in
				1) dosiero_parto="GNU+Linux x86.tar.bz2";;
				2) dosiero_parto="Mac OS x64.dmg";;
				3) dosiero_parto="Windows x86.zip";;
			esac
			wget -O "./GNU IceCat 38.8.0 ${dosiero_parto}" "http://ftpmirror.gnu.org/gnuzilla/38.8.0-gnu2/icecat-38.8.0.en-US.${ciu_celo}"
			ripeto=$((ripeto+1))
		done <<-CIU_CELO
			linux-i686.tar.bz2
			mac64.dmg
			win32.zip
		CIU_CELO
		unset ripeto
		
		mkdir "./lingvo" || exit 3
		while read -r ciu_lingvo; do
			wget -P "./lingvo" "http://ftpmirror.gnu.org/gnuzilla/38.8.0-gnu2/langpacks/icecat-38.8.0.${ciu_lingvo}.langpack.xpi"
		done <<-CIU_LINGVO
			eo
			en-GB
			en-US
			es-ES
			pt-BR
			pt-PT
		CIU_LINGVO
		
		cd "$malnova_pwd"
	fi
	if [ "$1" = "all" ] || [ "$1" = "ciuj" ] || [ "$1" = "kurso-de-esperanto" ]; then
		faraj_dosierujoj "Kurso de Esperanto"
		
		wget -P "./Fontodosieroj" "http://kurso.com.br/kurso4_source.tar.gz"
		
		ripeto=$((ripeto+1))
		while read -r ciu_celo; do
			case $ripeto in
				1) dosiero_parto="GNU+Linux x86.tar.gz";;
				2) dosiero_parto="Mac OS X.dmg";;
				3) dosiero_parto="Windows.exe";;
			esac
			wget -O "./Kurso de Esperanto 4.1.2 ${dosiero_parto}" "http://kurso.com.br/kurso.${ciu_celo}"
			ripeto=$((ripeto+1))
		done <<-CIU_CELO
			i386.tar.gz
			dmg
			exe
		CIU_CELO
		unset ripeto
		
		cd "$malnova_pwd"
	fi
	if [ "$1" = "all" ] || [ "$1" = "ciuj" ] || [ "$1" = "libreoffice" ]; then
		faraj_dosierujoj "LibreOffice"
		
		while read -r ciu_celo; do
			wget -P "./Fontodosieroj" "http://download.documentfoundation.org/libreoffice/src/5.2.0/libreoffice-${ciu_celo}5.2.0.4.tar.xz"
		done <<-CIU_CELO
			
			dictionaries-
			help-
			translations-
		CIU_CELO
		
		ripeto=$((ripeto+1))
		while read -r ciu_celo; do
			case $ripeto in
				1) dosiero_parto="GNU+Linux x86.deb.tar.gz";;
				2) dosiero_parto="Mac OS 10.8+ x86-64.dmg";;
				3) dosiero_parto="Windows x86.msi";;
			esac
			wget -O "./LibreOffice 5.2.0 ${dosiero_parto}" "http://download.documentfoundation.org/libreoffice/stable/5.2.0/${ciu_celo}"
			ripeto=$((ripeto+1))
		done <<-CIU_CELO
			deb/x86/LibreOffice_5.2.0_Linux_x86_deb.tar.gz
			mac/x86_64/LibreOffice_5.2.0_MacOS_x86-64.dmg
			win/x86/LibreOffice_5.2.0_Win_x86.msi
		CIU_CELO
		unset ripeto
		
		cd "$malnova_pwd"
	fi
	if [ "$1" = "all" ] || [ "$1" = "ciuj" ] || [ "$1" = "neverball" ]; then
		faraj_dosierujoj "Neverball"
		
		wget -P "./Fontodosieroj" "neverball.org/neverball-1.6.0.tar.gz"
		akiri_gnu_linux_fontodosieroj "neverball" "neverball-common" "neverball-data" "neverputt" "neverputt-data"
		
		akiri_gnu_linux_pakajo "neverball" "neverball-common" "neverball-data" "neverputt" "neverputt-data"
		wget -O "./Neverball 1.6.0 Windows.zip" "http://neverball.org/neverball-1.6.0.zip"
		
		cd "$malnova_pwd"
	fi
}

if [ ${#@} -eq 0 ]; then
	akiri_pakajo "ciuj"
else
	for parametro; do
		akiri_pakajo "$parametro"
	done
fi
